@@ -1,11 +1,10 @@
 from itertools import chain
 
-from admin_extra_urls.decorators import button
-from admin_extra_urls.mixins import _confirm_action
+from admin_extra_buttons.api import ExtraButtonsMixin, button, confirm_action
 from adminfilters.filters import AllValuesComboFilter, ChoicesFieldComboFilter, RelatedFieldComboFilter
+from adminfilters.mixin import AdminFiltersMixin
 from django.contrib.admin import FieldListFilter
 from django.contrib.admin.checks import BaseModelAdminChecks, must_be
-from django.contrib.admin.models import DELETION, LogEntry
 from django.contrib.admin.utils import flatten
 from django.contrib.contenttypes.models import ContentType
 from django.db import OperationalError, models
@@ -18,6 +17,8 @@ from django.utils.safestring import mark_safe
 from smart_admin.truncate import truncate_model_table
 from smart_admin.utils import get_related
 
+from .changelist import SmartChangeListMixin
+
 
 class SmartFilterMixin:
     def __init__(self, model, admin_site):
@@ -109,7 +110,8 @@ class ReadOnlyMixin:
         return self.readonly_fields
 
 
-class SmartMixin(ReadOnlyMixin, FieldsetMixin, DisplayAllMixin):
+class SmartMixin(ReadOnlyMixin, ExtraButtonsMixin, FieldsetMixin, DisplayAllMixin, SmartChangeListMixin,
+                 AdminFiltersMixin):
     readonly_fields = ()
 
 
@@ -143,6 +145,7 @@ class LinkedObjectsMixin:
 class TruncateAdminMixin:
     def _truncate(self, request):
         if request.method == "POST":
+            from django.contrib.admin.models import DELETION, LogEntry
             with atomic():
                 LogEntry.objects.log_action(
                     user_id=request.user.pk,
@@ -158,7 +161,7 @@ class TruncateAdminMixin:
                 except OperationalError:
                     self.get_queryset(request).delete()
         else:
-            return _confirm_action(
+            return confirm_action(
                 self,
                 request,
                 self.truncate,
