@@ -1,7 +1,7 @@
-from admin_extra_urls.decorators import button
-from admin_extra_urls.mixins import ExtraUrlMixin
+from admin_extra_buttons.api import ExtraButtonsMixin, button
 from adminfilters.autocomplete import AutoCompleteFilter
 from adminfilters.filters import AllValuesComboFilter, PermissionPrefixFilter
+from adminfilters.mixin import AdminFiltersMixin
 from django.apps import apps
 from django.contrib import admin
 from django.contrib.admin.utils import construct_change_message
@@ -20,11 +20,19 @@ from django.template.response import TemplateResponse
 from django.urls import reverse
 from django.utils.translation import gettext as _
 
+from ..views import SmartAutocompleteJsonView
+
 User = get_user_model()
 
 
+class SmartContentTypeJsonView(SmartAutocompleteJsonView):
+
+    def get_label(self, obj):
+        return f'{obj.name.title()} ({obj.app_label})'
+
+
 # @smart_register(ContentType)
-class ContentTypeAdmin(ExtraUrlMixin, admin.ModelAdmin):
+class ContentTypeAdmin(ExtraButtonsMixin, admin.ModelAdmin):
     list_display = ('app_label', 'model')
     search_fields = ('model',)
     list_filter = (('app_label', AllValuesComboFilter),)
@@ -38,6 +46,9 @@ class ContentTypeAdmin(ExtraUrlMixin, admin.ModelAdmin):
     def has_delete_permission(self, request, obj=None):
         return False
 
+    def autocomplete_view(self, request):
+        return SmartContentTypeJsonView.as_view(model_admin=self)(request)
+
     @button(permission='contenttypes.delete_contenttype')
     def check_stale(self, request):  # noqa
         context = self.get_common_context(request, title='Stale')
@@ -83,8 +94,7 @@ class ContentTypeAdmin(ExtraUrlMixin, admin.ModelAdmin):
                                     context)
 
 
-# @smart_register(Permission)
-class PermissionAdmin(ExtraUrlMixin, admin.ModelAdmin):
+class PermissionAdmin(ExtraButtonsMixin, AdminFiltersMixin, admin.ModelAdmin):
     list_display = ('name', 'content_type', 'codename')
     search_fields = ('name',)
     list_filter = (('content_type', AutoCompleteFilter),
@@ -116,7 +126,7 @@ class PermissionAdmin(ExtraUrlMixin, admin.ModelAdmin):
 
 
 # @smart_register(User)
-class UserAdmin(ExtraUrlMixin, _UserAdmin):
+class UserAdmin(ExtraButtonsMixin, AdminFiltersMixin, _UserAdmin):
     list_filter = ('is_staff', 'is_superuser', 'is_active',
                    ('groups', AutoCompleteFilter),
                    )
@@ -129,7 +139,7 @@ class UserAdmin(ExtraUrlMixin, _UserAdmin):
         context['permissions'] = sorted(context['original'].get_all_permissions())
         return render(request, 'admin/auth/user/permissions.html', context)
 
-    @button(urls=['redir_to_perm/(?P<perm>.*)/'])
+    @button(urls=['redir_to_perm/(?P<perm>.*)/$'])
     def redir_to_perm(self, request, perm):
         app_label, codename = perm.split('.')
         perm = Permission.objects.get(codename=codename, )
@@ -164,7 +174,7 @@ class UserAdmin(ExtraUrlMixin, _UserAdmin):
 
 
 # @smart_register(Group)
-class GroupAdmin(ExtraUrlMixin, _GroupAdmin):
+class GroupAdmin(ExtraButtonsMixin, _GroupAdmin):
     list_display = ('name',)
     search_fields = ('name',)
 
